@@ -142,10 +142,7 @@ write.landmarks<-function(x, file, format='amiralandmarks', ext=NULL, Force=FALS
       stop(dirname(file)," does not exist; use MakeDir=T to overwrite")
     }
   }
-  if(!file.access(file, mode=2)){
-    stop("Unable to write to file ",file)
-  }
-  
+
   # OK all fine, so let's write
   match.fun(fw$write)(x, file=file, ...)
   invisible(file)
