@@ -264,19 +264,18 @@ plot3d.hxsurf<-function(x, materials=NULL, col=NULL, ...){
 }
 
 #' Convert an object to an rgl mesh3d
-#'
-#' Note that this provides a link to the Rvcg package 
-#' @export
+#' 
+#' Note that this provides a link to the Rvcg package
 #' @param x Object to convert to mesh3d
 #' @param ... Additional arguments for methods
-as.mesh3d<-function(x, ...) UseMethod("as.mesh3d")
-
-#' @param Regions Character vector or regions to select from \code{hxsurf} object
+#' @param Regions Character vector or regions to select from \code{hxsurf}
+#'   object
 #' @param material rgl materials such as \code{color}
 #' @param drop Whether to drop unused vertices (default TRUE)
 #' @export
 #' @rdname as.mesh3d
-#' @seealso \code{\link[rgl]{tmesh3d}}
+#' @seealso \code{\link[rgl]{as.mesh3d}}, \code{\link[rgl]{tmesh3d}},
+#'   \code{\link{as.hxsurf}}, \code{\link{read.hxsurf}}
 #' @family hxsurf
 as.mesh3d.hxsurf<-function(x, Regions=NULL, material=NULL, drop=TRUE, ...){
   if(is.null(Regions)) {
@@ -292,6 +291,52 @@ as.mesh3d.hxsurf<-function(x, Regions=NULL, material=NULL, drop=TRUE, ...){
   tmesh3d(vertices=verts, indices=inds, homogeneous = FALSE, material = material, ...)
 }
 
+
+#' Convert an object to a nat hxsurf object
+#' 
+#' @details \code{hxsurf} objects are based on the format of Amira's surface 
+#'   objects (see \code{\link{read.hxsurf}}). They have the ability to include 
+#'   multiple distinct regions. However, at the moment the only method that we 
+#'   provide converts \code{mesh3d} objects, which can only include one region.
+#' @param x A surface object
+#' @param ... Additional arguments passed to methods
+#'   
+#' @return A new surface object of class \code{hxsurf} (see 
+#'   \code{\link{read.hxsurf}}) for details.
+#' @export
+#' @family hxsurf
+#' @seealso \code{\link{as.mesh3d}}
+#' @examples
+#' tet=tetrahedron3d(col='red')
+#' teth=as.hxsurf(tet)
+#' \donttest{
+#' plot3d(teth)
+#' }
+as.hxsurf <- function(x, ...) UseMethod('as.hxsurf')
+
+#' @param region The default name for the surface region
+#' @param col The surface colour (default value of NULL implies the colour
+#'   specified in mesh3d object or \code{grey} when the \code{mesh3d} object has
+#'   no colour.)
+#' @export
+#' @rdname as.hxsurf
+as.hxsurf.mesh3d <- function(x, region="Interior", col=NULL, ...) {
+  if (is.null(x$it))
+    stop("This method only works for triangular mesh3d objects!")
+  h=list()
+  h$Vertices=data.frame(xyzmatrix(x))
+  colnames(h$Vertices)=c("X","Y","Z")
+  h$Vertices$PointNo=1:nrow(h$Vertices)
+  h$Regions[[region]]=data.frame(t(x$it))
+  colnames(h$Regions[[region]])=c("V1","V2","V3")
+  h$RegionList=names(h$Regions)
+  if(is.null(col)) col=x$material$col
+  h$RegionColourList <- if(!is.null(col)) col else 'grey'
+  class(h)=c("hxsurf","list")
+  h
+}
+
+
 #' Subset hxsurf object to specified regions
 #' 
 #' @param x A dotprops object
